@@ -241,6 +241,9 @@ class VeracodeAPI:
 
     def get_teams(self, all_for_org=False):
         return Teams().get_all(all_for_org)
+    
+    def get_team_by_id(self, team_id):
+        return Teams().get(team_id)
 
     def create_team(self, team_name, business_unit: UUID = None, members=[]):
         return Teams().create(team_name, business_unit, members)
@@ -338,7 +341,7 @@ class VeracodeAPI:
         return Workspaces().revoke_agent_token(workspace_guid, agent_guid, token_id)
 
     def get_issues(self, workspace_guid: UUID, branch=None, created_after=None, direct=None, ignored=None, vuln_methods=None, project_id=None):
-        return Workspaces().get_issues(workspace_guid, branch=branch,created_after=created_after,direct=direct,ignored=ignored,vuln_methods=vuln_methods,project_id=None)
+        return Workspaces().get_issues(workspace_guid, branch=branch,created_after=created_after,direct=direct,ignored=ignored,vuln_methods=vuln_methods,project_id=project_id)
 
     def get_issue(self, issue_id: UUID):
         return Workspaces().get_issues(issue_id)
@@ -364,8 +367,8 @@ class VeracodeAPI:
     def get_component_activity(self, component_id):
         return ComponentActivity().get(component_id)
 
-    def get_sbom(self, app_guid: UUID):
-        return SBOM().get(app_guid)
+    def get_sbom(self, app_guid: UUID,format='cyclonedx',linked=False):
+        return SBOM().get(app_guid=app_guid,format=format,linked=linked)
 
     def get_sbom_project(self, project_guid: UUID):
         return SBOM().get_for_project(project_guid)
